@@ -74,6 +74,7 @@ def ProcessFiles(sourceFile):
             PrLightPurple('Traslating "' + sourceFile + '" from "' + sourceLang + '" to "' + targetLangs[i] + '"')
             langCombo = sourceLang + '-' + targetLangs[i]
             targetContent = ''
+            word = ''
             if fileName[-3:] == 'yml':
                 slicedApple = list(filter(lambda x: x != '' and x is not None, ymlRegex.split(sourceContent)))
                 with click.progressbar(slicedApple) as bar:
@@ -81,10 +82,10 @@ def ProcessFiles(sourceFile):
                         if not ymlRegex.fullmatch(piece):
                             targetContent += piece
                         else:
-                            word = Translate(piece[6:], langCombo).title()
+                            word = Translate(piece[6:], langCombo)
                             if word == None:
                                 break
-                            localized = 'name: ' + word
+                            localized = 'name: ' + word.title()
                             targetContent += localized
             else:
                 if sourceLang[:2] == 'en':
@@ -122,9 +123,10 @@ def ProcessFiles(sourceFile):
                             if type(localized) is list:
                                 localized = localized[0]
                             targetContent += localized
-            file = codecs.open(targetPaths[i] + '/' + '/'.join(sourceFile.split('/')[1:]), encoding = 'utf-8', mode = 'w+')
-            file.write(targetContent)
-            file.close()
+            if word != None:
+                file = codecs.open(targetPaths[i] + '/' + '/'.join(sourceFile.split('/')[1:]), encoding = 'utf-8', mode = 'w+')
+                file.write(targetContent)
+                file.close()
         return
     PrLightPurple('Copying "' + sourceFile + '"')
     for i in range (len(targetLangs)):
@@ -164,7 +166,7 @@ def Translate(text, langCombo):
                 'lang': langCombo,
                 'text': text
                 },
-            timeou = 1
+            timeout = 1.5
         )
     except requests.Timeout:
         PrYellow('A request timed out!')
